"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const objects_1 = require("@hypernetlabs/objects");
const core_1 = require("@material-ui/core");
const contexts_1 = require("../../contexts");
const react_1 = __importStar(require("react"));
const react_alert_1 = require("react-alert");
const components_1 = require("../../components");
const CreateIdentityWidget_1 = __importDefault(require("../../widgets/CreateIdentityWidget"));
const REGISTRY_ENTRIES_PER_PAGE = 3;
const RegistryEntryListWidget = ({ onRegistryEntryDetailsNavigate, onRegistryListNavigate, registryName, }) => {
    const alert = (0, react_alert_1.useAlert)();
    const { coreProxy, viewUtils } = (0, contexts_1.useStoreContext)();
    const { setLoading } = (0, contexts_1.useLayoutContext)();
    const [registryEntries, setRegistryEntries] = (0, react_1.useState)([]);
    const [registry, setRegistry] = (0, react_1.useState)();
    const [accountAddress, setAccountAddress] = (0, react_1.useState)((0, objects_1.EthereumAccountAddress)(""));
    const [reversedSortingEnabled, setReversedSortingEnabled] = (0, react_1.useState)(false);
    const [createIdentityModalOpen, setCreateIdentityModalOpen] = (0, react_1.useState)(false);
    const [page, setPage] = (0, react_1.useState)(1);
    const [hasEmptyState, setHasEmptyState] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        getRegistry();
    }, []);
    (0, react_1.useEffect)(() => {
        if (registry === null || registry === void 0 ? void 0 : registry.numberOfEntries) {
            getRegistryEntries(page);
        }
    }, [registry === null || registry === void 0 ? void 0 : registry.numberOfEntries, page, REGISTRY_ENTRIES_PER_PAGE]);
    (0, react_1.useEffect)(() => {
        getRegistryEntries(1);
    }, [reversedSortingEnabled]);
    (0, react_1.useEffect)(() => {
        coreProxy.getEthereumAccounts().map((accounts) => {
            setAccountAddress(accounts[0]);
        });
    }, []);
    const getRegistry = () => {
        coreProxy
            .getRegistryByName([registryName])
            .map((registryMap) => {
            const registry = registryMap.get(registryName);
            setRegistry(registry);
            setHasEmptyState(!(registry === null || registry === void 0 ? void 0 : registry.numberOfEntries));
            setLoading(false);
        })
            .mapErr(handleError);
    };
    const getRegistryEntries = (pageNumber) => {
        coreProxy
            .getRegistryEntries(registryName, pageNumber, REGISTRY_ENTRIES_PER_PAGE, reversedSortingEnabled
            ? objects_1.ERegistrySortOrder.REVERSED_ORDER
            : objects_1.ERegistrySortOrder.DEFAULT)
            .map((registryEntries) => {
            setRegistryEntries(registryEntries);
            setPage(pageNumber);
        })
            .mapErr(handleError);
    };
    const handleError = (err) => {
        setLoading(false);
        setHasEmptyState(true);
        alert.error((err === null || err === void 0 ? void 0 : err.message) || "Something went wrong!");
    };
    const isRegistrar = (0, react_1.useMemo)(() => {
        return registry === null || registry === void 0 ? void 0 : registry.registrarAddresses.some((address) => address === accountAddress);
    }, [accountAddress, JSON.stringify(registry === null || registry === void 0 ? void 0 : registry.registrarAddresses)]);
    const isRegistrationTokenEnabled = (0, react_1.useMemo)(() => {
        return ((registry === null || registry === void 0 ? void 0 : registry.registrationToken) != null &&
            !viewUtils.isZeroAddress(registry === null || registry === void 0 ? void 0 : registry.registrationToken));
    }, [JSON.stringify(registry === null || registry === void 0 ? void 0 : registry.registrationToken)]);
    const canCreateNewRegistryEntry = isRegistrar || isRegistrationTokenEnabled;
    return (react_1.default.createElement(core_1.Box, null,
        react_1.default.createElement(components_1.GovernanceWidgetHeader, { label: registryName, navigationLink: {
                label: "Registry Entry List",
                onClick: () => {
                    onRegistryListNavigate === null || onRegistryListNavigate === void 0 ? void 0 : onRegistryListNavigate();
                },
            }, ...(canCreateNewRegistryEntry && {
                headerActions: [
                    {
                        label: "Create New Identity",
                        onClick: () => setCreateIdentityModalOpen(true),
                        variant: "contained",
                        color: "primary",
                    },
                ],
            }), rightContent: react_1.default.createElement(core_1.Box, { display: "flex", alignItems: "center", marginTop: 5 },
                react_1.default.createElement(core_1.Typography, { style: { paddingRight: 5 } }, "Reverse sorting"),
                react_1.default.createElement(components_1.GovernanceSwitch, { initialValue: reversedSortingEnabled, onChange: (reversedSorting) => setReversedSortingEnabled(reversedSorting) })) }),
        hasEmptyState && (react_1.default.createElement(components_1.GovernanceEmptyState, { title: "No registiry entries found.", description: "Registiry entries submitted by community members will appear here." })),
        registryEntries.map((registryEntry) => (react_1.default.createElement(components_1.GovernanceRegistryListItem, { key: registryEntry.label, number: registryEntry.index != null
                ? (registryEntry.index + 1).toString()
                : "-", title: "", fieldWithValueList: [
                {
                    fieldTitle: "Label",
                    fieldValue: registryEntry.label || "-",
                },
                {
                    fieldTitle: "Token ID",
                    fieldValue: registryEntry.tokenId.toString(),
                },
                {
                    fieldTitle: "Owner",
                    fieldValue: registryEntry.owner || undefined,
                },
                {
                    fieldTitle: "Token URI",
                    fieldValue: registryEntry.tokenURI || undefined,
                },
            ], ...((isRegistrar || registryEntry.owner === accountAddress) && {
                actionButtonList: [
                    {
                        label: "View Registry Entry Details",
                        onClick: () => onRegistryEntryDetailsNavigate &&
                            onRegistryEntryDetailsNavigate(registryName, registryEntry.tokenId),
                    },
                ],
            }) }))),
        !!(registry === null || registry === void 0 ? void 0 : registry.numberOfEntries) && (react_1.default.createElement(components_1.GovernancePagination, { customPageOptions: {
                itemsPerPage: REGISTRY_ENTRIES_PER_PAGE,
                totalItems: registry === null || registry === void 0 ? void 0 : registry.numberOfEntries,
            }, onChange: (_, page) => {
                setPage(page);
            } })),
        createIdentityModalOpen && (react_1.default.createElement(CreateIdentityWidget_1.default, { onCloseCallback: () => {
                getRegistry();
                setCreateIdentityModalOpen(false);
            }, registryName: registryName, currentAccountAddress: accountAddress }))));
};
exports.default = RegistryEntryListWidget;
//# sourceMappingURL=RegistryEntryListWidget.js.map